@@ -9,15 +9,15 @@ makedocs(;
     sitename = "SymbolicAnalysis.jl",
     format = DocumenterVitepress.MarkdownVitepress(
         repo = "https://github.com/Vaibhavdixit02/SymbolicAnalysis.jl",
-        devurl = "dev",
+        devurl = "dev"
     ),
     pages = [
         "Home" => "index.md",
         "Examples" => "examples.md",
         "Atoms" => "atoms.md",
-        "Special Functions" => "functions.md",
+        "Special Functions" => "functions.md"
     ],
-    warnonly = true,
+    warnonly = true
 )
 
 deploydocs(; repo = "github.com/Vaibhavdixit02/SymbolicAnalysis.jl", push_preview = true)
