@@ -14,18 +14,19 @@ function add_gdcprule(f, manifold, sign, curvature, monotonicity)
     end
     gdcprules_dict[f] = makegrule(manifold, sign, curvature, monotonicity)
 end
-makegrule(manifold, sign, curvature, monotonicity) =
+function makegrule(manifold, sign, curvature, monotonicity)
     (manifold = manifold, sign = sign, gcurvature = curvature, gmonotonicity = monotonicity)
+end
 
 hasgdcprule(f::Function) = haskey(gdcprules_dict, f)
 hasgdcprule(f) = false
 gdcprule(f, args...) = gdcprules_dict[f], args
 
-setgcurvature(ex::Union{Symbolic,Num}, curv) = setmetadata(ex, GCurvature, curv)
+setgcurvature(ex::Union{Symbolic, Num}, curv) = setmetadata(ex, GCurvature, curv)
 setgcurvature(ex, curv) = ex
-getgcurvature(ex::Union{Symbolic,Num}) = getmetadata(ex, GCurvature)
+getgcurvature(ex::Union{Symbolic, Num}) = getmetadata(ex, GCurvature)
 getgcurvature(ex) = GLinear
-hasgcurvature(ex::Union{Symbolic,Num}) = hasmetadata(ex, GCurvature)
+hasgcurvature(ex::Union{Symbolic, Num}) = hasmetadata(ex, GCurvature)
 hasgcurvature(ex) = ex isa Real
 
 function mul_gcurvature(args)
@@ -35,7 +36,7 @@ function mul_gcurvature(args)
         @assert length(non_constants) <= 1
     catch
         @warn "DGCP does not support multiple non-constant arguments in multiplication"
-        return UnknownGCurvature
+        return GUnknownCurvature
     end
     if !isempty(non_constants)
         expr = args[first(non_constants)]
@@ -138,7 +139,7 @@ function find_gcurvature(ex)
                 end
             else
                 @warn "Disciplined Programming does not support multiple non-constant arguments in multiplication"
-                return UnknownGCurvature
+                return GUnknownCurvature
             end
         end
 
@@ -196,14 +197,13 @@ function find_gcurvature(ex)
     else
         return GLinear
     end
+    return GUnknownCurvature
 end
 
 function propagate_gcurvature(ex, M::AbstractManifold)
-    r = [
-        @rule *(~~x) => setgcurvature(~MATCH, mul_gcurvature(~~x))
-        @rule +(~~x) => setgcurvature(~MATCH, add_gcurvature(~~x))
-        @rule ~x => setgcurvature(~x, find_gcurvature(~x))
-    ]
+    r = [@rule *(~~x) => setgcurvature(~MATCH, mul_gcurvature(~~x))
+         @rule +(~~x) => setgcurvature(~MATCH, add_gcurvature(~~x))
+         @rule ~x => setgcurvature(~x, find_gcurvature(~x))]
     ex = Postwalk(Chain(r))(ex)
     ex = Prewalk(Chain(r))(ex)
     return ex
